:host(:not(.baz1)) {
  left: 0;
}

:not(:not(.baz2)) {
  left: 0;
}

a {
  :not(:not(.baz3)) {
    left: 0;
  }
}

q {

    .thing {
      color: black;
    }
  
    .a,
    .b,
    .c,
    .d,
    .e {
      &:not(.thing) { @extend .thing; }
    }

  }
  
:host(.abc1) { x: y; }
.a {@extend .abc1}

:not(.abc2) { x: y; }
.a {@extend .abc2}

:not(.thing) {
  color: red;
}
:not(.bar) {
  @extend .thing;
  background: blue;
}

:not(.foo1):not(:not(.ext1)) {
  color: red; }

a {
  :not(.foo2):not(:not(.ext2)) {
  color: red; }
}