:host(:not(.baz1)) {
  left: 0;
}

:not(:not(.baz2)) {
  left: 0;
}

a  {
  left: 0;
}

q .thing, q .a:not(.thing),
q .b:not(.thing),
q .c:not(.thing),
q .d:not(.thing),
q .e:not(.thing), q :not(.bar) {
  color: black;
}

:host(.abc1, .a) {
  x: y;
}

:not(.abc2):not(.a) {
  x: y;
}

:not(.thing) {
  color: red;
}

:not(.bar) {
  background: blue;
}

:not(.foo1):not(:not(.ext1)) {
  color: red;
}

a :not(.foo2) {
  color: red;
}
